@@ -351,11 +351,13 @@ def compare_phn_wrd_noise(timit_wav,
   #Phoneme Error Rate w/o noise
   timit_phoneme = read_phn(timit_phn,string=True)
   timit_phoneme = TIMIT_to_IPA(timit_phoneme)
-  initial_per = error_rate(timit_phoneme,asr_phoneme)
+  initial_per, xdf = error_rate(timit_phoneme,asr_phoneme)
+  del(xdf)
 
   #Word Error Rate w/o noise
   timit_text = file_text(timit_txt)[8:-1]
-  initial_wer = error_rate(timit_text,asr_txt,phn=False)
+  initial_wer, xdf = error_rate(timit_text,asr_txt,phn=False)
+  del(xdf)
 
   output_lst = [["Initial",initial_per['PER'],"PER"],["Initial",initial_wer["PER"],"WER"]]
 
@@ -367,12 +369,14 @@ def compare_phn_wrd_noise(timit_wav,
       #Phoneme ASR Model
       asr_phoneme_noise = asr_phn_model(louder_path_dir)
       asr_phoneme_noise = IPA_to_TIMIT(asr_phoneme_noise)
-      noise_per = error_rate(timit_phoneme,asr_phoneme_noise)
+      noise_per,xdf = error_rate(timit_phoneme,asr_phoneme_noise)
+      del(xdf)
       output_lst.append([f"+{vol}",noise_per['PER'],"PER"])
 
       #Word ASR Model
       asr_txt_noise = asr_txt_model(louder_path_dir)
-      noise_wer = error_rate(timit_text,asr_txt_noise,phn=False)
+      noise_wer,xdf = error_rate(timit_text,asr_txt_noise,phn=False)
+      del(xdf)
       output_lst.append([f"+{vol}",noise_wer['PER'],"WER"])
 
       #remove audio.wav
@@ -385,12 +389,14 @@ def compare_phn_wrd_noise(timit_wav,
       #Phoneme ASR Model     
       asr_phoneme_noise = asr_phn_model(softer_path_dir)
       asr_phoneme_noise = IPA_to_TIMIT(asr_phoneme_noise)
-      noise_per = error_rate(timit_phoneme,asr_phoneme_noise)
+      noise_per, xdf = error_rate(timit_phoneme,asr_phoneme_noise)
+      del(xdf)
       output_lst.append([f"-{vol}",noise_per['PER'],"PER"])
 
       #Word ASR Model
       asr_txt_noise = asr_txt_model(softer_path_dir)
-      noise_wer = error_rate(timit_text,asr_txt_noise,phn=False)
+      noise_wer,xdf = error_rate(timit_text,asr_txt_noise,phn=False)
+      del(xdf)
       output_lst.append([f"-{vol}",noise_wer['PER'],"WER"])
       
       #remove audio.wav
